library authentication_view;

import 'package:authentication_view/auth_colors.dart';
import 'package:flutter/material.dart';

import 'field_type.dart';

class AuthenticationView extends StatefulWidget {

  List<FieldType> fieldTypes;
  ValidationCallback onValidation;
  String buttonText;
  Widget headerLayout;
  List<FormFieldValidator> fieldValidators;

  AuthenticationView({this.fieldTypes, @required this.onValidation, this.buttonText, this.headerLayout, this.fieldValidators});

  @override
  _AuthenticationViewState createState() => _AuthenticationViewState();
}

class _AuthenticationViewState extends State<AuthenticationView> {
  final _formKey = GlobalKey<FormState>();

  List<FieldType> fieldTypes;
  ValidationCallback onValidation;
  String buttonText;
  Widget headerLayout;
  List<TextEditingController> textEditingControllers = [];
  List<FormFieldValidator> fieldValidators;
  int itemCount;

  @override
  void initState() {
    super.initState();
    fieldTypes = widget.fieldTypes ?? [FieldType.MOBILE, FieldType.PASSWORD];
    onValidation = widget.onValidation ?? null;
    buttonText = widget.buttonText ?? "CONTINUE";
    headerLayout = widget.headerLayout ?? Container(height: 0, width: 0);
    fieldValidators = widget.fieldValidators ?? null;
    fieldTypes = widget.fieldTypes ?? null;
    itemCount = fieldTypes != null && fieldTypes.isNotEmpty ? fieldTypes.length : 0;
    for(int i=0; i<itemCount; i++){
      textEditingControllers.add(TextEditingController());
    }
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisAlignment: MainAxisAlignment.start,
      children: <Widget>[
        headerLayout,
        SingleChildScrollView(
          padding: EdgeInsets.all(36),
          child: Form(
            key: _formKey,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                SizedBox(height: 24),
                ListView.builder(itemBuilder: (context, index){
                  return Container(
                    margin: EdgeInsets.only(bottom: 16),
                    child: TextFormField(
                        controller: textEditingControllers[index],
                        autofocus: true,
                        decoration: InputDecoration(
                            enabledBorder: UnderlineInputBorder(
                                borderSide: BorderSide(color: AuthColors.underline)),
                            focusedBorder: UnderlineInputBorder(
                              borderSide: BorderSide(color: AuthColors.green),
                            ),
                            hintStyle: TextStyle(color: AuthColors.text_grey),
                            hintText: fieldTypes[index].hint),
                        keyboardType: fieldTypes[index].keyboardType,
                        maxLength: fieldTypes[index].maxLength,
                        validator: fieldValidators[index]
                    ),
                  );
                }),
                SizedBox(height: 48),
                SizedBox(
                  width: 240,
                  height: 55,
                  child: FlatButton(
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(55))),
                    color: AuthColors.green,
                    textColor: Colors.white,
                    onPressed: () {
                      onValidation(_formKey.currentState.validate(), textEditingControllers);
                    },
                    child: Text(widget.buttonText),
                  ),
                ),
              ],
            ),
          ),
        ),
      ],
    );
  }
}

typedef ValidationCallback = void Function(bool isValidationSuccess, List<TextEditingController> textEditingControllers);
